<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 18/02/2019
 * Time: 10:33
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\City;
use App\Admin\Dashboard\Models\Store\Store;
use App\Admin\Role\Models\Role;
use App\Auth\Models\User;
use App\Core\Http\Controllers\CoreController;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class AdminUserController extends CoreController
{
    use DispatchesJobs;


    public function setUserPlan(Request $request)
    {

        $user_id = $request->get('user_id');
        $plan_id = $request->get('plan_id');

        $user = User::findOrFail($user_id);

        if ((int)$user->user_type === 3 || (int)$user->user_type === 4 ) {
            $response = new Response();
            $response->setStatusCode(403);
            $response->setContent(['success' => false, 'msg' => 'Usuário não pode ter plano ativado (particular/corretor)']);
            return $response;
        }

        if ((int)$user->is_aprovado !== 1) {
            // Check status atual (se for diferente de 1, liberar)
            $user->is_aprovado = 1;
            $user->save();
        }


        if ( in_array( $user->user_type, [1,2,5,6]) ) {
            // Check se usuário pertence a empresa
            $store = Store::where('user_id', $user_id)->first();

            // se não pertence: criar empresa e fazer o vínculo e vincular plano a empresa
            if (empty($store)) {
                // Localizar cidade
                $city = City::where('name', 'like',"%{$user->city}%")->first();

                // Criar empresa
                $store = Store::create([
                    'user_id' => $user->id,
                    'company_name' => $user->dealership,
                    'trade_name' => $user->dealership,
                    'cnpj' => $user->document,
                    'city_id' => !empty($city) ? $city->id : 999,
                    'neighborhood' => $user->neighborhood,
                    'street' => $user->address,
                    'number' => $user->number,
                    'status' => 1,
                    'zipcode' => $user->zipcode
                ]);
                // Vincular usuário a empresa
                $role_chief    = Role::where( 'name', 'chief' )->first();
                $role_business = Role::where( 'name', 'business' )->first();

                $store->staff()->attach( $user->id, ['role_id' => 2, 'status'=>1] );
                $user->roles()->attach( $role_chief->id );
                $user->roles()->attach( $role_business->id );

                $store->plans()->attach( $plan_id, ['status' => 1, 'created_at' => Carbon::now()->format('Y-m-d H:i:s')] );

            } else {
                // AQUI: isso deveria funcionar (inserir/editar)
                // Se pertence vincular plano a empresa
                $store->plans()->sync([1 => ['plan_id' => $plan_id, 'status' => 1, 'created_at' => Carbon::now()->format('Y-m-d H:i:s')]]);
            }

        } else {
            $role_individual = Role::where( 'name', 'individual' )->first();
            $user->roles()->attach( $role_individual->id );
        }




    }

}