<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 26/08/2019
 * Time: 14:12
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Http\Requests\CreateAdRequest;
use App\Admin\Dashboard\Models\Ads\Ad;
use App\Admin\Dashboard\Models\Ads\UserAd;
use App\Auth\Models\User;
use App\Auth\Models\UserType;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\Ads\ScheduleAd;
use App\Repasse\Ads\AdType;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Support\Facades\Storage;


class AvisoController extends CoreController
{
    use DispatchesJobs;

    public function index()
    {
        $user_types = UserType::all();
        $ads = Ad::orderBy('created_at', 'DESC')->paginate(10);
        // dd($user_types);
        return view('admin::avisos.index', compact('user_types', 'ads'));
    }

    public function create(CreateAdRequest $request)
    {
        $type = $request->get('type');
        $destination = $request->get(AdType::getKeyByType($type));
        $user_types = $request->get('user_type');
        $filename = $request->get('file_url');

        if ($request->hasFile('imagem')) {
            $file = $request->file('imagem');
            $extension = $file->getClientOriginalExtension();
            $filename = uniqid('REPAD_', true) . '.' . $extension;
            Storage::disk('ads')->put($filename, file_get_contents($file));

        }

        $ad = Ad::create([
            'name' => $request->get('name'),
            'filename' => $filename,
            'type' => $type,
            'destination'  => $destination,
            'user_type' => $user_types,
            'status' => 1
        ]);

        $job = (new ScheduleAd($ad, auth()->user()))->onQueue('Fipe');
        $this->dispatch($job);

        return redirect()->route('admin.products.avisos.index')->with('message', 'Aviso agendado com sucesso! Você vai receber um email assim que o aviso estiver no ar.');

    }

}