<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 10/10/2019
 * Time: 10:48
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\Store\Store;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\EditUserPodioJob;
use App\Repasse\Security\TokenGenerator;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;

class StoreController extends CoreController
{
    use DispatchesJobs;

    protected $user;

    public function __construct()
    {
        $this->user = auth()->user();
    }

    public function removePlan(Request $request)
    {
        // find or fail store
        $store = Store::findOrFail($request->get('store_id'));

        $store->plans()->detach();
        // Podio
        $podioJob = (new EditUserPodioJob($store->owner, $this->user))->onQueue('push');
        $this->dispatch($podioJob);


        return ['success' => true];
    }

    public function viewStore($store_id)
    {
        $store = Store::findOrFail($store_id);
        // send to view
        return view('admin::stores.index')->with('store', $store)->with('collapse', 'pesquisar');
    }

    public function generateToken(Request $request)
    {
        $store = Store::findOrFail($request->get('store_id'));
        $store->store_token = TokenGenerator::generate();
        $store->save();

        return ['success' => true];

    }

    public function changeSite(Request $request)
    {
        $store = Store::findOrFail($request->get('store_id'));
        $store->site = !$store->site;
        $store->save();

        return ['success' => true];
    }

    public function setSiteUrl(Request $request)
    {
        $store = Store::findOrFail($request->get('store_id'));
        $store->site_url = $request->get('url');
        $store->save();
        return ['success' => true];
    }

    public function changeDelivery($store_id)
    {
        $store = Store::findOrFail($store_id);
        $store->has_delivery = !$store->has_delivery;
        $store->save();
        return ['success' => true, 'store' => $store];
    }

}