<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 20/01/2017
 * Time: 14:06
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\Version;
use App\Core\Http\Controllers\CoreController;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class versaoController extends CoreController
{

    protected $request;
    protected $user;
    protected $version;


    public function __construct(Request $request, Auth $auth, Version $version) {
        $this->request = $request;
        $this->user = $auth::user();
        $this->version = $version;
    }

    public function index() {
        $versions = Version::all();
        return view('admin::dashboard.versao')->with('versions', $versions)->with('collapse', 'config');
    }

    public function store() {
        // Validate
        $params =  $this->request->only(['version', 'info', 'id']);
        $validation = Validator::make($params, [
            'version' => ['required'],
            'info' => ['required']
        ], [
            'required' => 'O campo precisa ser preenchido'
        ]);

        if($validation->fails()) {
            $response = new Response();
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => $validation->messages()]);
            return $response;
        }
        // Update
        $id = $this->request->get('id', null);
        if($id) {
            $version = Version::findOrFail($id);
            if($version) {
                $version->version = $this->request->get('version');
                $version->info = $this->request->get('info');
                if($version->save()) {
                    return ['success' => true, 'data' => $version];
                }
            }
        }

        // Save
        $version = Version::create([
            'user_id' => $this->user->id,
            'version' => $params['version'],
            'info'    => $params['info'],
            'current' => 0
        ]);
        if($version->save()) {
            return ['success' => true, 'data' => $version ];
        } else {
            $response = new Response();
            $response->setStatusCode(500);
            $response->setContent(['success' => false, 'msg' => 'Falha ao salvar os dados']);
            return $response;
        }
    }

    public function setCurrent() {
        $version_id = $this->request->get('id');

        DB::transaction(function() use($version_id) {
            $antigas = Version::where('current', 1)->update(['current' => 0]);
            $version = Version::find($version_id);
            $version->current = 1;
            $version->save();
        });

        return ['success' => true, 'msg' => 'Alterado com sucesso'];
    }

    public function getVersion() {
        $version_id = $this->request->get('id');
        $version = Version::findOrFail($version_id);
        return ['success' => true, 'data' => $version];
    }

    public function removeVersion() {
        $version_id = $this->request->get('id');
        $version = Version::findOrFail($version_id);
        if($version->delete()) {
            return ['success' => true, 'msg' => 'Removido com sucesso'];
        }
    }

}