<?php

namespace App\Admin\Dashboard\Models;

use Illuminate\Database\Eloquent\Model;
use App\Admin\Dashboard\Models\Brand;
use Illuminate\Support\Facades\DB;

/**
 * @SWG\Definition(type="object", @SWG\Xml(name="Fipe"))
 */
class Fipe extends Model
{

    /**
     * @var integer
     * @SWG\Property()
     */
    private $id;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $modelo_id;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $brand_id;

    /**
     * @var string
     * @SWG\Property()
     */
    private $year;

    /**
     * @SWG\Property()
     */
    private $fuel;

    /**
     * @var string
     * @SWG\Property()
     */
    private $code;

    /**
     * @var double
     * @SWG\Property()
     */
    private $price;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $type;

    /**
     * @var string
     * @SWG\Property()
     */
    private $model;

    protected $table = 'fipe';

    protected $fillable = ['name', 'brand_id', 'model', 'year', 'fuel', 'code', 'price', 'external_fipe_id', 'modelo_id'];

    protected $hidden = ['created_at', 'updated_at'];

    protected $appends = ['fipe_combustivel'];

    public function brand(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
       return $this->belongsTo(Brand::class, 'brand_id');
    }

    public function modelo(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(Modelo::class, 'modelo_id');
    }

    public static function listOrfaos()
    {
        return DB::table('fipe')
            ->join('brand', 'fipe.brand_id', '=', 'brand.id')
            ->join('car_types', 'fipe.type', '=', 'car_types.id')
            ->where('modelo_id', 0)
            ->groupBy('code')
            ->select('brand.name as marca', 'car_types.name as tipo', 'fipe.*')
            ->get();

    }

    public function tipo()
    {
        return $this->belongsTo(CarType::class, 'type', 'id');
    }

    public function getFipeCombustivelAttribute()
    {
        switch ($this->attributes['fuel']) {
            case 'Diesel':
                return 3;
            case 'Gasolina':
                return 1;
            case 'Alcool':
                return 2;
        }
    }

}
