<?php

namespace App\Admin\Dashboard\Models\Order;

use App\Auth\Models\User;
use App\Repasse\Products\Order\MoipOrderStatus;
use Illuminate\Database\Eloquent\Model;
use App\Admin\Dashboard\Models\CarQuery\CarQuery;
use App\Admin\Dashboard\Models\OrderItem\OrderItem;

/**
 * @SWG\Definition(type="object", @SWG\Xml(name="Order"))
 */
class Order extends Model
{
    protected $fillable = [
        'user_id',
        'total',
        'subtotal',
        'discount',
        'transaction_code',
        'status',
        'order_id',
        'order_status',
        'checkout_link'
    ];

    protected $appends = ['situation'];

    /**
     * @var object
     * @SWG\Property()
     */
    private $user;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $total;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $subtotal;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $discount;

    /**
     * @var string
     * @SWG\Property()
     */
    private $transaction_code;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $status;

    public function user()
    {
        return $this->hasOne(User::class, 'id', 'user_id');
    }

    public function items()
    {
        return $this->hasMany(OrderItem::class, 'order_id', 'id');
    }

    public function car_query()
    {
        return $this->hasOne(CarQuery::class);
    }


    public function getSituationAttribute()
    {
        return MoipOrderStatus::getStatus($this->attributes['order_status']);
    }
}
