<?php

namespace App\Admin\User\Http\Controllers;

use App\Admin\Dashboard\Models\City;
use App\Admin\Dashboard\Models\State;
use App\Admin\Dashboard\Models\Store\Store;
use App\Admin\User\Http\Requests\UserRequest;
use App\Auth\Models\UserType;
use App\Core\Http\Controllers\CoreController as CoreController;
use App\Core\Jobs\EditUserPodioJob;
use App\Core\Jobs\Podio\RemoveDataPodioJob;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Response;
use Redirect;
use App\Auth\Models\User;
use App\Admin\Role\Models\Role;
use Mailgun;

class UserController extends CoreController
{
    use DispatchesJobs;

    protected $user;

    public function __construct()
    {
        $this->user = auth()->user();
    }

    public function index()
    {
        $users = User::all();
        return view('admin::user.index')->with(compact('users'));
    }

    public function edit($id)
    {

        $states = State::orderBy('name', 'asc')->get();
        $ar_states = ['' => 'Selecione...'];
        foreach ($states as $state) {
            $ar_states[$state->id] = $state->name;
        }

        $user = User::findOrFail($id);

        $selected_state_id = null;
        $selected_city_id = null;

        if ($user->state) {
            $selected_state = State::where('initials', $user->state)->select('id')->get();
            $selected_city = City::where('stateId', $selected_state[0]->id)->where('name',
                $user->city)->select('id')->get();

            $selected_state_id = $selected_state[0]->id;
            $selected_city_id = $selected_city[0]->id;
        }
        $userTypes = UserType::select('id', 'name')->get();
        $ar_types = [];
        foreach ($userTypes as $type) {
            $ar_types[$type->id] = $type->name;
        }


        return view('admin::user.form')
            ->with(compact('user'))
            ->with('particulares', [Store::PARTICULAR_STORE, Store::CORRETOR_STORE])
            ->with('state', $ar_states)
            ->with('selected_state', $selected_state_id)
            ->with('selected_city', $selected_city_id)
            ->with('user_types', $ar_types);
    }

    public function show($id)
    {
    }

    public function create()
    {
        $roles = Role::orderBy('name', 'asc')->get();
        $ar_role = ['' => 'Selecione...'];
        foreach ($roles as $role) {
            $ar_role[$role->id] = $role->name;
        }

        $states = State::orderBy('name', 'asc')->get();
        $ar_states = ['' => 'Selecione...'];
        foreach ($states as $state) {
            $ar_states[$state->id] = $state->name;
        }

        return view('admin::user.form')
            ->with('role', $ar_role)
            ->with('state', $ar_states);
    }

    public function store(UserRequest $request)
    {
        $user = new User();
        $user->fill($request->all());

        if ($user->save()) {
            return Redirect::route('admin.user.index');
        } else {
            return Redirect::route('admin.user.create');
        }
    }

    public function update($id, UserRequest $request)
    {
        $user = User::findOrFail($id);
        $current_type = (int)$user->user_type;
        $next_type = (int)$request->get('user_type');

        $user->name = $request->get('name');
        $user->email = $request->get('email');
        $user->document = preg_replace("/\D/", '', $request->get('document'));
        $user->dealership = $request->get('dealership');
        $user->phone = preg_replace("/\D/", '', $request->get('phone'));
        $user->cell_phone = preg_replace("/\D/", '', $request->get('cell_phone'));
        $user->user_type = $request->get('user_type');
        $user->is_flagged = $request->get('is_flagged');

        if ($user->save()) {

            if ($current_type !== $next_type) {
                // Ocorreu uma alteração de tipo de usuário
                // Sair de todas as lojas
                $user->stores()->detach();
                if (UserType::isProfessional($next_type)) {
                    // Lojista/Repassador/Concessionária/Locadora
                    // Roles do usuário professional (diretor/business)
                    $roles = Role::getProfessionalRole();
                    // Encontrar a loja do usuário que ele é dono e attach to staff
                    // se não existir, criar a loja
                    $store = Store::where('user_id', $user->id)->first();

                    if (empty($store)) {
                        // Criar a loja com base nos dados do usuário
                        $city = City::where('name', 'like',"%{$user->city}%")->first();
                        $store = Store::create([
                            'user_id' => $user->id,
                            'company_name' => $user->dealership,
                            'trade_name' => $user->dealership,
                            'cnpj' => $user->document,
                            'city_id' => !empty($city) ? $city->id : 999,
                            'neighborhood' => $user->neighborhood,
                            'street' => $user->address,
                            'number' => $user->number,
                            'status' => 0,
                            'zipcode' => $user->zipcode
                        ]);
                    }
                    // Vincular usuário a loja
                    $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status' => 1 ] );


                } else {

                    // Particulares
                    $roles = Role::getIndividualRole();
                    switch($next_type) {
                        // Particular
                        case 3:
                            $loja = Store::getParticularStore();
                            break;
                        case 4:
                            $loja = Store::getCorretorStore();
                            break;
                        default:
                            $loja = null;
                            break;
                    }
                    $loja->staff()->attach($user->id, ['role_id' => $roles[0], 'status' => 1]);

                }

                $user->roles()->sync($roles);
            }

            $editUserJob = (new EditUserPodioJob($user, $this->user))->onQueue('push');
            $this->dispatch($editUserJob);
            return Redirect::route('admin.user.edit', ['id' => $id])->with('message', 'Usuário alterado com sucesso!');
        } else {
            return Redirect::route('admin.user.edit', ['id' => $id])->withInputs();
        }
    }

    function destroy($id, Response $response)
    {
        $user = User::findOrFail($id);
        $podio_id = $user->podio_id;

        if ($user->delete()) {
            // Remover do podio
            if ($podio_id) {
                $job = (new RemoveDataPodioJob($podio_id))->onQueue('push');
                $this->dispatch($job);
                $response->setContent(['success' => true, 'msg' => 'Usuário removido com sucesso! Solicitação de remoção do podio enviada!']);
                return $response;
            }
            return ['success' => true, 'msg' => 'Usuário removido com sucesso! Atenção: Item não possui vinculo informado com o Podio, efetuar exclusão manualmente!'];
        } else {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Usuário não pode ser removido!']);
            return $response;
        }
    }

    function getCities($state_id)
    {

        $cities = City::where('stateId', $state_id)->get()->toArray();

        return array('data' => $cities);
    }
}
