<?php

namespace App\Api\Http\Controllers;

use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\Room;
use App\Auth\Models\User;
use App\Chat\Room\RoomFactory;
use App\Http\Requests\Conversas\CreateConversaRequest;
use App\Repasse\CarUtil;
use Illuminate\Support\Facades\Auth;
use App\Core\Http\Controllers\CoreController;
use Illuminate\Support\Facades\Log;

class ApiConversasController extends CoreController
{
    /**
     * @var $user User
     */
    private $user;

    public function __construct(Auth $auth)
    {
        $this->user = $auth::user();
    }

    /**
     * @SWG\Get(path="/conversas",
     *   tags={"Conversas"},
     *   summary="Lista as conversas",
     *   description="",
     *   operationId="list",
     *   produces={"application/json"},
     *    @SWG\Parameter( in="path", name="page", description="Página da requisição", required=false, type="integer" ),
     *   @SWG\Response( response=200, description="",
     *       @SWG\Schema(
     *           @SWG\Property(property="success", type="boolean"),
     *           @SWG\Property(property="data", type="object", ref="#/definitions/CepDTO"
     *           )
     *       )
     *   ),
     *   @SWG\Response( response=400, description="",
     *       @SWG\Schema(
     *           @SWG\Property( property="error", type="string", description="Bad Request" )
     *       )
     *   )
     * )
     * @param integer $page
     * @return \Illuminate\Http\Response
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function list(int $page = 1)
    {

       $conversas = \DB::table('rooms')
            ->join('car', 'car.id', '=', 'rooms.car_id')
            ->where('comprador_id', '=', $this->user->id)
            ->orWhere('car.user_id', '=', $this->user->id)
            ->orderBy('rooms.updated_at', 'DESC')
            ->limit(1500)
            ->select('rooms.*')
            ->get();

        foreach ($conversas as &$conversa) {
            Log::info('um car', [$conversa]);
            $conversa->comprador = User::with('type')->find($conversa->comprador_id);
            $car = Car::find($conversa->car_id);
            if ($car) {
                $carUtil = new CarUtil($car);
                $conversa->car = $carUtil->getCarObject($this->user->id);
            }
            /*if ($conversa->anuncio) {
                $carUtil = new CarUtil($conversa->anuncio);
                $conversa->car = $carUtil->getCarObject($this->user->id);
                unset($conversa->anuncio);
            }*/
        }
        // $total = count($conversas);

        return $this->returnData($conversas);
    }

    /**
     * @SWG\Post(
     *     path="/conversas",
     *     tags={"Conversas"},
     *     summary="Cria uma nova conversa",
     *     description="",
     *     @SWG\Parameter(
     *         name="body",
     *         in="body",
     *         required=true,
     *         @SWG\Schema(
     *             type="object",
     *             @SWG\Property(
     *                 property="car_id",
     *                 type="integer",
     *                 description="Id do carro"
     *             )
     *
     *         )
     *     ),
     *      @SWG\Response(
     *         response=200,
     *         description="Resposta de sucesso",
     *         @SWG\Schema(
     *             type="object",
     *             @SWG\Property(
     *                 property="success",
     *                 type="boolean",
     *                 description="Indica se a operação foi bem-sucedida"
     *             ),
     *             @SWG\Property(
     *                 property="data",
     *                 type="object",
     *                 @SWG\Property(
     *                     property="link",
     *                     type="string",
     *                     description="Link associado"
     *                 ),
     *                 @SWG\Property(
     *                     property="phone",
     *                     type="string",
     *                     description="Telefone associado"
     *                 )
     *             )
     *         )
     *     ),
     *     @SWG\Response(
     *         response=400,
     *         description="Dados inválidos"
     *     )
     * )
     */
    public function create(CreateConversaRequest $request)
    {
        // cria a sala
        $carId = $request->get('car_id');
        $room = RoomFactory::create($carId, $this->user->id);
        $room_id = $room->getRoomId();
        // pega o telefone do caboclo
        $car = Car::find($carId);
        $data = [
            'phone' => $car->user->cell_phone,
            'link' => "https://wa.me/+55{$car->user->cell_phone}&text=",
        ];

        return $this->returnData($data);

    }

}