<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 17/07/2017
 * Time: 15:19
 */

namespace App\Api\Http\Controllers;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\ContactType;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\NewContactPodioJob;
use App\Repasse\CarUtil;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class ApiOpenController extends CoreController
{
    use DispatchesJobs;

    public function ofertas(Request $request)
    {
        /*
         * A ideia desse controller é trazer informações truncadas
         * mas que possam ser usadas para mkt. Nesse endpoint
         * X ofertas começando da página Y. Nao retorna nenhum
         * dado identificavel de usuario nem do anúncio em si
         */
        $page = $request->input('page');
        $size = $request->input('size');

        $response = new Response();
        // prevenindo abusos
        if ($size > 20) {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Solicite menos carros']);
            return $response;


        }

        $cars = Car::whereIn('car.car_status_id', [9, 1])
            ->join('user', 'car.user_id', '=', 'user.id')
            ->where('car.site_only', false)
            ->where('user.is_aprovado', 1)
            ->orderBy('car.published_at', 'DESC')
            ->limit($size)->offset(($page - 1) * $size)
            ->select('car.*')
            ->get();

        $ar_cars = [];

        foreach ($cars as $car) {
            $carUtil = new CarUtil($car);
            $ar_cars[] = $carUtil->getShortObject();
        }


        return ['success' => true, 'data' => $ar_cars];

    }


    public function formContatoLead(Request $request, Response $response): Response
    {

        // validar
        $this->validate($request,
            [
                'nome' => 'required',
                'sobrenome' => 'required',
                'ddd' => 'required',
                'celular' => 'required',
                'email' => 'required|email',
                'estado' => 'required',
                'cidade' => 'required'
            ],
            [
                'required' => 'O campo precisa ser preenchido.',
                'email' => 'Email informado é inválido'
            ]);

        // enviar
        $data = $request->only([
            'nome',
            'sobrenome',
            'ddd',
            'celular',
            'email',
            'estado',
            'cidade',
            'profissional',
            'mensagem'
        ]);

        $job = (new NewContactPodioJob($data))->onQueue('push');
        $this->dispatch($job);

        $response->setContent(['success' => true, 'msg' => 'Contato enviado com sucesso!']);

        return $response;

    }

}