<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 21/07/2017
 * Time: 11:00
 */

namespace App\Api\Http\Controllers;


use App\Admin\Dashboard\Models\UserRating;
use App\Auth\Models\User;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\Podio\SendUserReviewPodioJob;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;
use Log;

class ApiRatingsController extends CoreController
{

    use DispatchesJobs;

    protected $request;
    protected $user;

    public function __construct(Request $request, Auth $auth) {
        $this->request = $request;
        $this->user    = $auth::user();
    }

    /**
     * se is_rated for true o usuário será
     * encaminhado a tela de avaliação do
     * app ao entrar
     * @return array
     */
    public function getStatus() {
        $userId = $this->user->id;
        // Aqui a gente verifica se o usuário já fez a avaliação.
        $userRating = UserRating::where('user_id', $userId)->first();
        // Verificar se a data de cadastro do usuário é menor que uma semana, se sim considerar ele como true (não envia para avaliar)
        $semana = Carbon::now()->subWeek();
        $user  = User::where('id', $userId)->where('created_at', '<', $semana->endOfDay()->toDateTimeString() )->first();

        $is_rated = false;
        if ( $userRating || !$user) {
            $is_rated = true;
        }

        return ['success' => true, 'data' => ['is_rated' => $is_rated]];

    }

    public function store() {
        $userId = $this->user->id;
        $dados = [
            'user_id' => $userId,
            'rating' => (int)$this->request->get('rating'),
            'observation' => $this->request->get('avaliacao', ''),
            'fipe' => (int)$this->request->get('fipe')
        ];

        Log::debug('Nova avaliacao recebida', $dados);

        $rating = $this->request->get('rating');
        if ( $rating == 0 ) {
            $response = new Response();
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Os campo avaliação (estrelas) e valor da fipe são obrigatórios']);
            return $response;
        }

        // Verificar (e dispensar) caso já exista uma avaliação
        $oldRating = UserRating::where('user_id', $userId)->first();

        if(!$oldRating) {
            $userRating = UserRating::create($dados);
            $job = (new SendUserReviewPodioJob($userRating))->onQueue('push');
            $this->dispatch($job);
        }

        return ['success' => true, 'msg' => 'Criado com sucesso'];


    }

}