<?php

namespace App\Core\Console\Commands;

use Moip;
use Illuminate\Console\Command;
use App\Admin\Dashboard\Models\Order\Order;
use Berkayk\OneSignal\OneSignalFacade as OneSignal;

class PaymentCheck extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'payment:check';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Verifica o status de pagamento das consultas pendentes.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $moip   = Moip::start();
        $orders = Order::where( 'status', 0 )->get();
        $status = [
            'CREATED'  => 0,
            'WAITING'  => 0,
            'PAID'     => 1,
            'NOT_PAID' => 2,
            'REVERTED' => 3,
        ];

        foreach ( $orders as $_order ) {
            if ( !is_null( $_order->user->device_token ) ){
                $message =
                OneSignal::sendNotificationCustom([
                    'contents' => [
                        'en'    => 'O status de pagamento da sua consulta foi atualizado.',
                        'pt-BR' => 'O status de pagamento da sua consulta foi atualizado.',
                    ],
                    'data' => [
                        'order_id' => $_order->id,
                    ],
                    'include_player_ids' => $_order->user->device_token
                ]);
            }

            $order_moip = $moip->orders()->get( $_order->transaction_code );
            $payment_status = $status[$order_moip->getStatus()];
            $_order->fill(['status'=>$payment_status])->save();
        }
    }
}
