<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 23/07/2019
 * Time: 15:22
 */

namespace App\Core\Console\Commands\Podio;


use App\Auth\Models\User;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Storage;
use League\Csv\Writer;
use SplTempFileObject;
use Repasse\LaravelPodio\Services\PodioService;

class UpdateLastSeen extends Command
{

    protected $signature = 'podio:lastseen {date?}';

    protected $description = 'Atualiza o visto por último do Podio';


    public function handle(PodioService $podioService)
    {


        $date = $this->argument('date');

        if (!$date) {
            $date = Carbon::now()->subHours(1)->toDateTimeString();
        }
        $appUser = $podioService->getApp('Usuários');
        $app_id = (int)$appUser['id'];


        // Gerar csv
        $dados = User::where('is_aprovado', 1)->where('role_id', 2)->where('last_seen', '>', $date);

        $resultado = $dados->get(['id', 'last_seen'])->toArray();

        if (count($resultado) > 0) {
            $csv = Writer::createFromFileObject(new SplTempFileObject());
            $csv->setDelimiter(',');
            $csv->setEnclosure('"');
            $csv->insertOne(['id', 'last_seen']);
            $csv->insertAll($resultado);

            // dd($csv->getContent());
            $filename = uniqid('lastseen_', true) . '.csv';
            Storage::disk('lastseen')->put($filename, $csv->__toString());
            // upload file to podio
            // $file = Storage::path()->disk('lastseen')->get($filename);

            $podioFile = \PodioFile::upload(storage_path('lastseen') . '/' . $filename, $filename);
            // $fileupload = $podioFile->

            $importer = \PodioImporter::process_app($podioFile->file_id, $app_id, [
                'app_id' => $app_id,
                'mappings' => [
                    ['field_id' => (int)$appUser['id_field'], 'unique' => true, 'value' => ['column_id' => '0', 'value_column_id' => 'id']],
                    [
                        'field_id' => (int)$appUser['lastseen_field'],
                        'unique' => false,
                        'value' => ['start_column_id' => '1', 'value_column_id' => 'last_seen', 'day_first' => true]
                    ]
                ],
                'app_item_id_column_id' => '0'
            ]);
        }



    }


}