<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 08/11/2018
 * Time: 20:04
 */

namespace App\Core\Console\Commands;


use App\Auth\Models\User;
use App\Core\Jobs\PushNotificationJob;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Log;


class PushNewSeller extends Command
{
    use DispatchesJobs;

    protected $signature = 'push:newseller';

    protected $description = 'Envia push notification incentivando novos usuários a fazer anúncios';

    protected $heading = 'Você tem veículos para Repassar?';

    protected $contents = 'Não fique de fora, não deixe seus repasses parados. Anuncie agora e comece a negociar';

    protected $data = ['car' => true];

    protected $days = 5;

    public function handle()
    {
        Log::info('Iniciando a rotina de envio de push para novos usuários que não fizeram anúncios ');

        $date = Carbon::now()->subDays($this->days)->toDateString();

        // dd($date);
        $users = User::leftJoin('car', 'car.user_id', '=', 'user.id')
            ->where('is_aprovado', 1)
            ->where('role_id', 2)
            ->where('device_token', '<>', " ''  " )
            ->whereRaw(" CAST( user.created_at AS DATE) =  '{$date}' ")
            ->groupBy('user.id')
            ->havingRaw('count(car.id) = 0')
            ->select('user.device_token', \DB::raw('COUNT(car.id) AS anuncios'))->get();


        if ($users) {
            $devices = array_pluck($users->toArray(), 'device_token');

            $parameters = [
                'include_player_ids' => $devices,
                'headings' => [
                    'en' => $this->heading
                ],
                'contents' => [
                    'en' => $this->contents
                ],
                'android_group' => 7,
                'android_group_message' => [
                    'en' => '$[notif_count] Aviso(s)'
                ],
                'small_icon' => 'repasse_small_icon_white',
                'large_icon' => 'repasse_icon',
                'data' => $this->data
            ];

            $job = (new PushNotificationJob($parameters))->onQueue('push');
            $this->dispatch($job);
        }


        Log::info('Finalizada a rotina de envio de push para novos usuários que não fizeram anúncios ');
    }
}