<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 01/11/2018
 * Time: 11:07
 */

namespace App\Core\Console\Commands;


use App\Admin\Dashboard\Models\Car;
use App\Auth\Models\User;
use App\Core\Jobs\PushNotificationJob;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Log;

class PushSellAgain extends Command
{

    use DispatchesJobs;

    protected $signature = 'push:sellagain';

    protected $description = 'Envia Push incentivando usuário a fazer um novo anúncio';

    protected $heading = 'Já vendeu seu veículo?';

    protected $contents = 'Você tem veículos de repasse parados? Anuncie agora e comece a negociar.';

    protected $data = ['car' => true];

    protected $days = 3;

    public function handle()
    {
        Log::info('Iniciando a rotina de envio de push de incentivo a anunciar novamente');
        $date = Carbon::now()->subDays($this->days)->toDateString();

        // listar todos os anúncios que a data de publicação é a 3 dias atrás com status em aberto
        $anuncios = Car::whereRaw(" CAST( published_at AS DATE) = '{$date}' ")->get(['user_id']);
        if (!empty($anuncios)) {
            // Listar anúncios publicados a mais de três dias
            $array_usuarios = array_pluck($anuncios->toArray(), 'user_id');
            $anuncios_novos = Car::whereRaw(" CAST( published_at AS DATE) > '{$date}' ")->whereIn('user_id',
                $array_usuarios)->get(['user_id']);

            $anunciantes_recentes = array_pluck($anuncios_novos->toArray($anuncios_novos), 'user_id');

            $anuncios_usuarios = Car::whereRaw(" CAST( published_at AS DATE) = '{$date}' ")->whereNotIn('user_id',
                $anunciantes_recentes)->get(['user_id']);

            if ($anuncios_usuarios) {
                $array_usuarios = array_pluck($anuncios_usuarios->toArray(), 'user_id');
                // Esta é a lista de ids trazer os usuários poderia usar a chave estrangeira mas isso geraria uma nova query pra cada carro. Dessa forma limitamos a duas consultas
                $users = User::where('is_aprovado', 1)->distinct()->where('device_token', '<>', " ''  " )->whereIn('id',
                    $array_usuarios)->get(['device_token']);
                if (!empty($users)) {
                    $devices = array_pluck($users->toArray(), 'device_token');

                    $parameters = [
                        'include_player_ids' => $devices,
                        'headings' => [
                            'en' => $this->heading
                        ],
                        'contents' => [
                            'en' => $this->contents
                        ],
                        'android_group' => 7,
                        'android_group_message' => [
                            'en' => '$[notif_count] Aviso(s)'
                        ],
                        'small_icon' => 'repasse_small_icon_white',
                        'large_icon' => 'repasse_icon',
                        'data' => $this->data
                    ];

                    $job = (new PushNotificationJob($parameters))->onQueue('push');
                    $this->dispatch($job);

                }

            }

        }

        Log::info('Finalizada rotina de envio de push de incentivo a anunciar novamente');

    }

}