<?php
/**
 * Created by PhpStorm.
 * User: Marcelo Teodoro
 * Date: 18/05/2023
 * Time: 16:24
 */

namespace App\Core\Jobs\Fipe;


use App\Admin\Dashboard\Models\Brand;
use App\Core\Jobs\Job;
use GuzzleHttp\Client;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use App\Admin\Dashboard\Models\Config;

class AtualizaFipe extends Job implements ShouldQueue
{

    use InteractsWithQueue, SerializesModels, DispatchesJobs;

    private $marca;
    private $config;
    private $brand_id;
    private $year;

    public function __construct(Config $config, Brand $marca, $brand_id, $year)
    {
        $this->config = $config;
        $this->marca = $marca;
        $this->brand_id = $brand_id;
        $this->year = $year;
    }

    public function handle()
    {
        $client = new Client();

        $request = $client->request('POST', config('fipe.api.url') . '/v1/modelos', ['json' => [
            'codigo_tabela' => $this->config->current_fipe_table_id,
            'tipo_veiculo' => $this->marca->tipo->external_fipe_id,
            'codigo_marca' => $this->marca->external_fipe_id,
            'ano_combustivel' => "{$this->year}-1"
        ]]);
        $dadosModelosFipe = json_decode($request->getBody());

        $job = (new AtualizaModelosMarcaFipeJob($dadosModelosFipe, $this->brand_id, $this->marca->tipo->id))->onQueue('Fipe');
        $this->dispatch($job);

        $job = (new AtualizaFipePorModeloAno($this->config, $this->marca, $this->brand_id, $this->year, $dadosModelosFipe))->onQueue('Fipe');
        $this->dispatch($job);
    }
}