<?php
/**
 * Created by PhpStorm.
 * User: Marcelo Teodoro
 * Date: 18/05/2023
 * Time: 16:24
 */

namespace App\Core\Jobs\Fipe;


use App\Admin\Dashboard\Models\Brand;
use App\Admin\Dashboard\Models\Fipe;
use App\Admin\Dashboard\Models\Modelo;
use App\Core\Jobs\Job;
use GuzzleHttp\Client;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Log;
use App\Admin\Dashboard\Models\Config;

class AtualizaFipePorModeloAno extends Job implements ShouldQueue
{

    use InteractsWithQueue, SerializesModels, DispatchesJobs;

    private $marca;
    private $config;
    private $brand_id;
    private $year;
    private $dadosModelosFipe;

    public function __construct(Config $config, Brand $marca, $brand_id, $year, $dadosModelosFipe)
    {
        $this->config = $config;
        $this->marca = $marca;
        $this->brand_id = $brand_id;
        $this->year = $year;
        $this->dadosModelosFipe = $dadosModelosFipe;
    }

    public function handle()
    {
        $client = new Client();
        $modelosFipe = $this->dadosModelosFipe->Modelos;

        foreach ($modelosFipe as $modelofipe) {

            /*Necessario verificar pois quando o modelo de carro passado é inexistente, o formato vem sem value */
            if(property_exists($modelofipe, 'Value')) {
                $modeloBase = Fipe::where('external_fipe_id', (int)$modelofipe->Value)->get()->first();

                if(empty($modeloBase)) {

                    $veiculofiperequest = $client->request('POST', config('fipe.api.url') . '/v1/veiculo', ['json' => [
                        'tipo_veiculo'    => $this->marca->tipo->external_fipe_id,
                        'codigo_tabela'   => $this->config->current_fipe_table_id,
                        'codigo_marca'    => $this->marca->external_fipe_id,
                        'codigo_modelo'   => $modelofipe->Value,
                        'ano_combustivel' => "{$this->year}-1"
                    ]]);

                    $veiculofipe = json_decode($veiculofiperequest->getBody());

                    $modelo_name = explode(' ', $veiculofipe->Modelo)[0];
                    $modelo = Modelo::where('name', $modelo_name)
                        ->where('car_type', $this->marca->type)
                        ->get()
                        ->first();

                    if($modelo === null) {
                        $modelo = (object) [
                            'id' => ''
                        ];
                    }

                    $novoVeiculo = [
                        'modelo_id' => $modelo->id,
                        'model' => $modelofipe->Label,
                        'brand_id' => $this->brand_id,
                        'year' => $veiculofipe->AnoModelo,
                        'fuel' => $veiculofipe->Combustivel,
                        'code' => $veiculofipe->CodigoFipe,
                        'price' => str_replace(['R$ ', '.', ','], ['', '', '.'], trim($veiculofipe->Valor)),
                        'type' => $this->marca->type,
                        'external_fipe_id' => $modelofipe->Value,
                    ];

                    Log::debug('O modelo ' . $veiculofipe->AnoModelo .' '. $modelofipe->Label . ' não foi encontrado na Base e será criado.');
                    Fipe::create($novoVeiculo);

                }
            }
        }
    }
}