<?php

namespace App\Core\Jobs;

use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarPush;
use App\Admin\Dashboard\Models\UserProfile;
use App\Auth\Models\User;
use App\Core\Jobs\Job;
use App\Push\PushNotification;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\SerializesModels;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Config;
use Log;

class NewCarJob extends Job implements SelfHandling, ShouldQueue
{
    use InteractsWithQueue, SerializesModels, DispatchesJobs;

    protected $car;

    /** @var bool $turbo */
    protected $turbo;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct($car, $turbo = false)
    {
        //
        $this->car = $car;
        $this->turbo = $turbo;

    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        Log::info('Iniciando a rotina de publicação do anúncio: ' . $this->car->id);


        if ($this->turbo) {
            Log::info('Iniciando a rotina de publicação do anúncio Turbo: ' . $this->car->id);

            $CarAgora = Car::find($this->car->id);

            if ( !$CarAgora || (int)$CarAgora->car_status_id !== 9 ) {
                Log::info('O anúncio não pode ser impulsionado pois não está mais patrocinado: ' . $this->car->id);
                $carPush = new CarPush();
                $carPush->car_id = $this->car->id;
                $carPush->eligible_tokens = 0;
                $carPush->sent_push = 0;
                $carPush->save();
                return ;
            }
        }


        // Filter info
        $ddd_ad = $this->car->user_ddd;
        $car_type = $this->car->car_type;
        $car_year = $this->car->year;
        $car_owner = $this->car->user->id;
        $car_image = $this->car->image;
        // Push Message info
        $car_name =  $this->car->brand->name . ' ' . $this->car->fipe->model ;
        $car_city = $this->car->user->city . '/' . $this->car->user->state;
        // Destino info

        $publico = $this->car->published_to;

        $query = '
                 select
                 p.*,
                 c.car_type as car_type,
                 s.ddd as DDD,
                 u.device_token as device_token,
                 u.muted_until as muted_until,
                 u.user_type as user_type
                 from user_profile p
                 join user_profile_car_type c on c.profile_id = p.id
                 join user_profile_ddd d on d.profile_id = p.id
                 join state_ddds s ON s.id = d.ddd_id
                 join user u ON u.id = p.user_id
                 where p.user_id <> :user_id
                 AND DDD = :ddd_ad
                 AND car_type = :car_type
                 AND :car_year BETWEEN p.start_year AND p.end_year';

        $queryParameters = [
            'user_id' => $car_owner,
            'ddd_ad' => $ddd_ad,
            'car_type' => $car_type,
            'car_year' => $car_year
        ];
        $notificaveis = \DB::select($query, $queryParameters);

        $url = Config::get('app.url') . '/uploads/gallery/' . $car_image;

        $parameters = [
            'include_player_ids' => [],
            'headings' => [
                'en' => "Novo veículo cadastrado em {$car_city}"
            ],
            'contents' => [
                'en' => "{$car_name} cadastrado"
            ],
            'android_group' => 2,
            'android_group_message' => [
                'en' => '$[notif_count] novos anúncios'
            ],
            'small_icon' => 'repasse_small_icon_white',
            'large_icon' => 'repasse_icon',
            'big_picture' => $url,
            'data' => ['car' => true]
        ];

        foreach ($notificaveis as $destinatario) {
            if ($destinatario->device_token != null) {
                $muted_until = Carbon::createFromFormat('Y-m-d H:i:s', $destinatario->muted_until);
                if (!$muted_until->isFuture() ) {
                    if ( in_array($destinatario->user_type, $publico, true) ) {
                        $parameters['include_player_ids'][] = $destinatario->device_token;
                        Log::debug('Usuário id: '. $destinatario->user_id .' é destinatário de push pela regra de perfil');
                    }
                }
            }
        }

        // Notificar quem não tem perfil

        $user_profile_id = UserProfile::get(['user_id']);

        $noProfile = User::where('id', '<>', $this->car->user->id)
            ->where('user_type', '<>', 3)
            ->whereNotIn('id', $user_profile_id)
            ->get();

        foreach ($noProfile as $destinatario) {
            if ($destinatario->device_token != null && isUuid($destinatario->device_token)) {
                if ( !$destinatario->muted_until->isFuture() ) {
                    if ( in_array($destinatario->user_type, $publico, true) ) {
                        $parameters['include_player_ids'][] = $destinatario->device_token;
                        Log::debug('Usuário id: '. $destinatario->id .' é destinatário de push pela regra de usuários sem perfil');
                    }

                }
            }
        }

        // Usuários administrativos
        $admins = User::where('role_id', 1)->get();
        foreach ( $admins as $admin ) {
            if ($admin->device_token != null && isUuid($admin->device_token)) {
                $parameters['include_player_ids'][] = $admin->device_token;
            }
        }

        // Enviar
        if (!empty($parameters['include_player_ids'])) {
            $qtdPl = \count($parameters['include_player_ids']);
            $carPush = new CarPush();
            $carPush->sent_push = 0;
            $carPush->car_id = $this->car->id;
            $carPush->eligible_tokens = $qtdPl;

            Log::info("Player ids localizados {$qtdPl} Mandando push");

            $push = new PushNotification();
            $dados_envio = $push->sendCustom($parameters);

            if ($dados_envio) {
                Log::debug("Dados envio push car id {$this->car->id} ",[$dados_envio]);
                $parsed_dados = json_decode($dados_envio);
                if (isset($parsed_dados->recipients)) {
                    $carPush->sent_push = (int)$parsed_dados->recipients;
                }
            }
            $carPush->save();

        } else {
            Log::info('Zero destinatários para o push');
        }

        // Publicar:

        /** @var Car $car_publish */
        $car_publish =  Car::find($this->car->id);

        $car_publish->published_at = Carbon::now();

        if (!$this->turbo) {
            $car_publish->car_status_id = 1;
            $podioJob = (new CarStatusPodioJob($car_publish, 1))->onQueue('push');
            $this->dispatch($podioJob);
        } else {
            $podioJob = (new CarStatusPodioJob($car_publish, 9))->onQueue('push');
            $this->dispatch($podioJob);
        }

        $car_publish->save();
    }
}
