<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 24/07/2019
 * Time: 16:07
 */

namespace App\Core\Jobs\Podio;


use App\Admin\Dashboard\Models\UserRating;
use App\Core\Jobs\Job;
use App\Core\Jobs\NewUserPodioJob;
use App\Repasse\Integration\Podio\Fields\AppField;
use App\Repasse\Integration\Podio\Models\UserRatingFields;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Repasse\LaravelPodio\Services\PodioService;

class SendUserReviewPodioJob extends Job implements SelfHandling, ShouldQueue
{
    use SerializesModels, InteractsWithQueue, DispatchesJobs;

    protected $rating;

    public function __construct(UserRating $rating)
    {
        $this->rating= $rating;
    }

    public function handle(PodioService $podioService)
    {
        $appUser = $podioService->getApp('Usuários');
        $appRatings = $podioService->getApp('Avaliações');

        if (!$podioService->isAuthenticated()) {
            $podioService->authenticateWithPassword();
        }

        // Configuração do campo origem da avaliação
        $origem = AppField::get($appRatings['id'], $appRatings['origin_field'], $podioService);
        $attributes['origin_field'] =  ['name' => $appRatings['origin_field'], 'data' => $origem ];

        $userRatingFields = new UserRatingFields($this->rating, $attributes);
        $fields = $userRatingFields->toPodio();

        if (!$this->rating->user->podio_id) {
            // Procurar no app usuários a referência númerica em id-usuario-2
            $user = \PodioItem::filter($appUser['id'], [
                'limit' => 1,
                'filters' => [
                    'id-usuario-2' => [
                        'from' => (int)$this->rating->user->id,
                        'to' => (int)$this->rating->user->id
                    ]
                ]
            ]);

            if ($user[0]) {
                $this->rating->user->podio_id = $user[0]->item_id;
                $this->rating->user->save();
                $fields['fields']['relacionamento'] = $this->rating->user->podio_id;
            } else {

                $podioJob = (new NewUserPodioJob($this->rating->user))->onQueue('push');
                $this->dispatch($podioJob);

                // Release job to queue
                $this->release(20);
            }
        }

        $podioItem = \PodioItem::create($appRatings['id'], $fields);

    }

}