<?php

namespace App\Core\Jobs;

use App\Auth\Models\User;
use App\Core\Jobs\Job;
use Illuminate\Queue\SerializesModels;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Support\Facades\Mail;

class SendWelcomeEmail extends Job implements SelfHandling, ShouldQueue
{

    use InteractsWithQueue, SerializesModels;


    private $user;
    private $password;
    private $link;

    /**
     * Create a new job instance.
     *
     * @param $user User
     * @param $password string
     * @param $link string
     */
    public function __construct($user, $password, $link)
    {
        $this->user = $user;
        $this->password = $password;
        $this->link = $link;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle(Mail $mail)
    {
        /*
         * Passar no array
         * Nome da pessoa
         * Endereço de e-mail
         * Senha (this->password)
         * Link para desbloquear o usuário
         * @TODO existe o link de validação de email, caso necessário
         */
        $mail::send('emails.confirmaremail', [
            'name' => $this->user->name,
            'email' => $this->user->email,
            'password' => $this->password,
            'link' => $this->link
        ], function( $message ) {
            $message->to($this->user->email, $this->user->name)->subject('Parabéns pelo cadastro!');
        });

    }
}
