<?php

namespace App\Repasse\Integration\Cep\BrasilApi;

use App\Repasse\Integration\Cep\CepFetchInterface;
use App\Repasse\Integration\Cep\DTO\FetchCepDTO;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Cache;

class BrasilApiFetch implements CepFetchInterface
{
    private $client;

    const SITE_URL = 'https://brasilapi.com.br';

    public function __construct()
    {
        $this->client = new Client(['base_uri' => self::SITE_URL]);
    }

    public function fetchCep($cep): FetchCepDTO
    {
        //
        $cep = preg_replace("/[^0-9]/", "", $cep);
        try {
            $body = Cache::get("BrasilApi_{$cep}", function() use ($cep) {
                $res = $this->client->request('GET', "/api/cep/v2/{$cep}");
                return json_decode($res->getBody());
            });

            if ($body) {
                return BrasilApiFetchFactory::make($body);
            }
        } catch (GuzzleException $exception) {
            throw $exception;
        }

    }
}