<?php

namespace App\Repasse\Integration\Cep\ViaCep;

use App\Repasse\Integration\Cep\CepFetchInterface;
use App\Repasse\Integration\Cep\DTO\FetchCepDTO;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Cache;

class ViaCepFetch implements CepFetchInterface
{

    const SITE_URL = 'https://viacep.com.br/ws/';

    private $client;

    public function __construct()
    {
        $this->client = new Client(['base_uri' => self::SITE_URL]);
    }

    public function fetchCep($cep): FetchCepDTO
    {
        try {
            $body = Cache::get("viacep_{$cep}", function() use ($cep) {
                $res = $this->client->request('GET', "ws/{$cep}/json/");
                return json_decode($res->getBody());

            });

            if ($body) {
                return ViaCepFetchFactory::make($body);
            }
        } catch (GuzzleException $exception) {
            throw $exception;
        }
    }

}