<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 05/12/2018
 * Time: 12:09
 */

namespace App\Repasse\Integration\Podio\Models;


use App\Admin\Dashboard\Models\Car;
use App\Repasse\TimeParser;

class CarFields implements FieldsInterface
{
    protected $data = [
        'external_id' => null,
        'fields' => [
            'modelo' => null,
            'cliente' => null,
            'usuario' => null,
            'id-anuncio-2' => null,
            'status' => null,
            'marca' => null,
            'ano-2' => null,
            'cor-2' => null,
            'km' => null,
            'preco' => ['value' => null, 'currency' => 'BRL'],
            'preco-fipe' => ['value' => null, 'currency' => 'BRL'],
            'data-do-cadastro' => ['start' => null],
            'descricao' => null

        ]
    ];

    public function __construct(Car $car, array $attributes)
    {

        $this->data['external_id'] = (string)$car->id;
        $this->data['fields']['modelo'] = $car->fipe->model;
        $this->data['fields']['cliente'] = $car->user->podio_id ? (int)$car->user->podio_id : null;
        $this->data['fields']['usuario'] = $car->user->name;
        if ($car->user->city) {
            $this->data['fields']['cidade'] = $car->user->city;
            $this->data['fields']['estado'] = $car->user->state;
        }
        $this->data['fields']['id-anuncio-2'] = $car->id;
        $this->data['fields']['marca'] = $car->brand->name;
        $this->data['fields']['ano-2'] = (string)$car->year;
        $this->data['fields']['cor-2'] = $car->color->name;
        $this->data['fields']['km'] = (string)$car->km;
        $this->data['fields']['preco']['value'] = $car->price;
        $this->data['fields']['preco-fipe']['value'] = $car->fipe_price;
        $this->data['fields']['data-do-cadastro']['start'] = TimeParser::toSqlString($car->created_at);
        $this->data['fields']['descricao'] = $car->observation;
        $this->data['fields']['status'] = $car->car_status->podio_id;

        // Para carros que já existem, checar data de publicação
        if ($car->published_at > 0) {
            $this->data['fields']['data-do-anuncio'] = TimeParser::toSqlString($car->published_at);
        }

        if (isset($attributes['user_type_field'])) {
            $key = array_search($car->user->type->name, array_column($attributes['user_type_field']['data']->config['settings']['options'], 'text'));
            $result = $attributes['user_type_field']['data']->config['settings']['options'][$key]['id'];
            $this->data['fields'][$attributes['user_type_field']['name']] = $result;
        }

    }

    public function toPodio(): array
    {

        if ($this->data['external_id'] === null) {
            throw new \InvalidArgumentException('Missing data');
        }

        return $this->data;
    }
}