<?php

namespace App\Repasse\Services;

use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarPhoto;
use Image;


class ImageService
{
    const MARGIN = 5;

    const WIDTH = 600;

    const HEIGHT = 450;

    public static function makeSingleImage($file1, $file2, $file3, $file4)
    {
        // Configuração de margens
        $margin = self::MARGIN; // Tamanho da margem entre as imagens

        // Dimensões da imagem original
        $image1Width = self::WIDTH;
        $image1Height = self::HEIGHT;

        // Calcula as dimensões do canvas
        $canvasWidth = $image1Width + (2 * $margin); // Adiciona margens laterais
        $imageRowHeight = ($image1Height / 3);      // Altura proporcional para as imagens inferiores
        $canvasHeight = $image1Height + $imageRowHeight + (3 * $margin); // Altura total incluindo margens

        // Cria o canvas principal com fundo branco
        $canvas = Image::canvas($canvasWidth, $canvasHeight, '#ffffff');

        // Carrega a imagem 1 e posiciona no topo com margens
        $image1 = Image::make($file1)->resize($image1Width, $image1Height);
        $canvas->insert($image1, 'top', 0, $margin); // Margem no topo

        // Calcula dimensões para as imagens de baixo
        $imageWidth = ($canvasWidth - (4 * $margin)) / 3; // Divide largura com margens
        $imageHeight = $imageRowHeight;

        // Carrega e redimensiona as imagens 2, 3 e 4
        $image2 = Image::make($file2)->resize($imageWidth, $imageHeight);
        $image3 = Image::make($file3)->resize($imageWidth, $imageHeight);
        $image4 = Image::make($file4)->resize($imageWidth, $imageHeight);

        // Insere as imagens 2, 3 e 4 com margens uniformes
        $canvas->insert($image2, 'bottom-left', $margin, $margin); // Imagem 2 no canto inferior esquerdo
        $canvas->insert($image3, 'bottom', 0, $margin);           // Imagem 3 no centro da fileira inferior
        $canvas->insert($image4, 'bottom-right', $margin, $margin); // Imagem 4 no canto inferior direito

        return $canvas;
    }

    public static function randomName($extension)
    {
        return uniqid() . time() . '.' . $extension;

    }

    private static function prepareImages(array $images): array
    {
        return array_map(function ($image) {
            return public_path() . CarPhoto::IMAGE_PATH . $image['filename'];
        }, $images);

    }

    public static function generateSaveImage(Car $car)
    {
        $carImages = $car->photos()->limit(4)->get()->toArray();
        $imagePaths = self::prepareImages($carImages);

        $generatedImage = self::makeSingleImage($imagePaths[0], $imagePaths[1], $imagePaths[2], $imagePaths[3]);

        $filename = self::randomName('jpeg');
        $generatedImage->save(public_path() . CarPhoto::IMAGE_PATH . $filename);
        $car->sharefilename = $filename;

        return $car->save();
    }

}