<?php

namespace App\Repasse\UserControl;

use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarIncident;
use App\Auth\Models\User;
use App\Chat\Agent;
use App\Core\Jobs\CarStatusPodioJob;
use App\Core\Jobs\EditUserPodioJob;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\SerializesModels;

/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 14/02/2017
 * Time: 15:38
 * O objetivo dessa classe é receber uma tabela usuário e uma carro e, na função block travar todos os anúncios
 * de um usuário de uma só vez
 */
class Block
{
    use DispatchesJobs, SerializesModels;

    /** @var User $user */
    protected $user;

    /** @var Car $car */
    protected $car;

    protected $requestUser;

    public function __construct(User $user, Car $car, $requestUser)
    {
        $this->user = $user;
        $this->car = $car;
        $this->requestUser = $requestUser;
    }

    public function block($user_id): bool
    {
        // Procurar todos os anúncios com status = 1 e colocar status 7 (bloqueado) com motivo: usuário suspenso
        $anuncios = $this->car->where('user_id', $user_id)->where('car_status_id', 1)->get();
        $car_status_id = 7;
        $arr_anuncios = [];
        foreach ($anuncios as $anuncio) {
            $denuncias = CarIncident::where('car_id', $anuncio->id)->where('status', 1)->get();
            if ($denuncias) {
                foreach ($denuncias as $d) {
                    $d->status = 0;
                    $d->save();
                }
            }
            $arr_anuncios[] = $anuncio->id;
            $anuncio->car_status_id = $car_status_id;
            $anuncio->reason = 'O usuário foi bloqueado';
            $anuncio->save();

            $podioJob = (new CarStatusPodioJob($anuncio, $car_status_id))->onQueue('push');
            $this->dispatch($podioJob);
            unset($podioJob);
        }
        // alterar o status do usuário para zero
        $user = $this->user->find($user_id);
        $user->is_aprovado = 0;
        $user->save();

        $editUserJob = (new EditUserPodioJob($user, $this->requestUser))->onQueue('push');
        $this->dispatch($editUserJob);

        // Bloqueio no chat para todos que tem room com ele?
        $host = config('chat.host');
        $port = config('chat.port');
        $token = config('chat.token');
        $message = [
            'sender_id' => $user_id,
            'receiver_id' => null,
            'car_id' => null, // alterar no foreach
            'car_status_id' => $car_status_id
        ];

        $agent = new Agent($host, $port, $token);
        foreach ($arr_anuncios as $id) {
            $message['car_id'] = $id;
            $agent->sendMessage($message);
        }

        return true;
    }

}