<?php

namespace App\Transformers\Car;

use App\Transformers\Transformer;
use App\Admin\Dashboard\Models\Room;


/**
 * @SWG\Definition(type="object", @SWG\Xml(name="CarTransformer"))
 */
class CarTransformer extends Transformer
{

    /**
     * @var integer
     * @SWG\Property()
     */
    private $id;

    /**
     * @var string
     * @SWG\Property()
     */
    private $model;

    /**
     * @var string
     * @SWG\Property()
     */
    private $fuel;

    /**
     * @var string
     * @SWG\Property()
     */
    private $color;

    /**
     * @var string
     * @SWG\Property()
     */
    private $year;

    /**
     * @var double
     * @SWG\Property()
     */
    private $cost;

    /**
     * @var double
     * @SWG\Property()
     */
    private $price;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $interested;

    /**
     * @var boolean
     * @SWG\Property()
     */
    private $has_chat;

    /**
     * @var double
     * @SWG\Property()
     */
    private $fipe_price;

    /**
     * @var string
     * @SWG\Property()
     */
    private $fipe_percent_off;

    /**
     * @var object
     * @SWG\Property(type="object",
     *     @SWG\Property(property="id", type="integer"),
     *     @SWG\Property(property="name", type="string"),
     *     @SWG\Property(property="phone", type="string"),
     *     @SWG\Property(property="cell_phone", type="string"),
     *     @SWG\Property(property="photo", type="string"))
     */
    private $user;

    /**
     * @var object
     * @SWG\Property(type="object",
     *     @SWG\Property(property="filename", type="string"),
     *     @SWG\Property(property="photo_order", type="string"))
     */
    private $photos;

    /**
     * @var object
     * @SWG\Property(type="object",
     *     @SWG\Property(property="id", type="integer"),
     *     @SWG\Property(property="name", type="string"))
     */
    private $status;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $badge;

    /**
     * @var array
     * @SWG\Property(type="array", @SWG\Items(type="integer"))
     */
    private $bids;

    /**
     * @var string
     * @SWG\Property()
     */
    private $created_at;

    /**
     * @var string
     * @SWG\Property()
     */
    private $updated_at;

    public function transform( $value )
    {
        $badge = 0;
        $bids = [];

        $rooms = Room::where( 'car_id', $value->id )->orderBy('bid', 'desc')->get();
        foreach($rooms as $room) {
            $badge += $room->badges($value->user->id);
            $bids[] = $room->bid;
        }
        $chats = $rooms->count();

        return [
            'success' => true,
        	'data' => [
	        	'id'               => (integer)$value->id,
                'name'             => $value->fipe->model,
                'fuel'             => $value->fipe->fuel,
                'color'            => $value->color->name,
                'year'             => $value->fipe->year,
                'cost'             => $value->cost,
                'price'            => $value->price,
                'interested'       => $value->calls()->count() + $chats,
                'fipe_price'       => $value->fipe_price,
                'user'             => [
                    'id'         => $value->user->id,
                    'name'       => $value->user->name,
                    'phone'      => $value->user->phone,
                    'cell_phone' => $value->user->cell_phone,
                ],
                'status'           => $value->car_status_id,
                'badge'            => $badge,
                'bids'             => array_slice($bids, 0, 3),
                'created_at'       => date( 'Y-m-d H:i:s', strtotime( $value->created_at ) ),
                'updated_at'       => date( 'Y-m-d H:i:s', strtotime( $value->updated_at ) )
	        ]
        ];
    }

    public function transformCollection ( $values )
    {
        $status = [
            '0' => 'Sem Status definido',
            '1' => 'Em aberto',
            '2' => 'Negociando',
            '3' => 'Vendido',
            '4' => 'Em cadastro',
            '5' => 'Em analise',
            '6' => 'Suspenso',
            '7' => 'Bloqueado',
            '8' => 'Excluido',
            '9' => 'Turbo',
        ];

        $data = [];
        foreach ( $values as $value ) {

            $photos = [];
            foreach ( $value->photos as $_val ) {
                $photos[] = [
                    'filename'    => $_val->filename,
                    'photo_order' => $_val->photo_order
                ];
            }


            $badge = 0;
            $bids = [];

            $rooms = Room::where( 'car_id', $value->id )->orderBy('bid', 'desc')->get();
            foreach($rooms as $room) {
                $bids[] = $room->bid;
                if ($room->badges($value->user->id) > 0 ) {
                    ++$badge;
                }
            }
            $chats = $rooms->count();
            $has_chat = (bool)$chats;

            $data[] = [
                'id'               => (integer)$value->id,
                'model'            => $value->fipe->model,
                'fuel'             => $value->fipe->fuel,
                'color'            => $value->color->name,
                'year'             => $value->fipe->year,
                'cost'             => $value->cost,
                'price'            => $value->price,
                'interested'       => $value->calls()->count() + $chats,
                'has_chat'         => $has_chat,
                'fipe_price'       => $value->fipe_price,
                'fipe_percent_off' => number_format( ( $value->price - $value->fipe_price ) / $value->fipe_price * 100 ) . '%',
                'user'             => [
                    'id'         => $value->user->id,
                    'name'       => $value->user->name,
                    'phone'      => $value->user->phone,
                    'cell_phone' => $value->user->cell_phone,
                ],
                'photos'           => $photos,
                'status'           => [
                    'id'   => $value->car_status_id,
                    'name' => $status[$value->car_status_id],

                ],
                'badge'            => $badge,
                'bids'             => array_slice($bids, 0,2),
                'created_at'       => date( 'Y-m-d H:i:s', strtotime( $value->created_at ) ),
                'updated_at'       => date( 'Y-m-d H:i:s', strtotime( $value->updated_at ) )
            ];
        }

        return [
            'success' => true,
            'data'  => [
                'totals'       => $values->total(),
                'per_page'     => $values->perPage(),
                'current_page' => $values->currentPage(),
                'items'        => $data,
            ]
        ];
    }
}