<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiControllerPublishCarTest extends TestCase
{
    use DatabaseTransactions;

    public function testCarNotFound()
    {
        $response = $this->call('POST', '/api/car-publish',
            ['id' => 9999999], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJsonEquals(['success' => false, 'msg' => 'Anúncio não encontrado!'])->assertResponseStatus(404);

    }

    public function testCarIdNotSent()
    {

        $response = $this->call('POST', '/api/car-publish',
            [], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJsonEquals(['success' => false, 'msg' => 'Falta um parâmetro'])->assertResponseStatus(400);

    }

    public function testCarFromAnotherUser()
    {

        $response = $this->call('POST', '/api/car-publish',
            ['id' => 1702], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJsonEquals(['success' => false, 'msg' => 'Acesso negado'])->assertResponseStatus(403);

    }

    public function testCarAlreadyPublished()
    {
        $response = $this->call('POST', '/api/car-publish',
            ['id' => 1706], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJsonEquals(['success' => false, 'msg' => 'Anúncio já foi publicado'])->assertResponseStatus(412);
    }

    public function testBellowAmmountPhotos()
    {
        $car = \App\Admin\Dashboard\Models\Car::find(1706);
        $car->car_status_id = 4;
        $car->photos()->delete();
        $car->save();

        $response = $this->call('POST', '/api/car-publish',
            ['id' => 1706], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJsonEquals(['success' => false, 'msg' => 'A quantidade de fotos difere da solicitada (entre 4 e 10)'])->assertResponseStatus(409);
    }

    public function testNoPublic()
    {
        $response = $this->call('POST', '/api/car-publish',
            ['id' => 1490], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJson(['success' => false, 'msg' => 'Você precisa escolher um público para este anúncio'])->assertResponseStatus(400);

    }



    public function testPublishCar()
    {

        $this->expectsJobs([\App\Core\Jobs\NewCarJob::class]);
        $response = $this->call('POST', '/api/car-publish',
            ['id' => 1490, 'user_types' => [1,2,3,4,5,6]], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJson(['success' => true])->assertResponseStatus(201);
        $this->seeInDatabase('car_publish', ['car_id' => 1490, 'user_type' => 1]);


    }

    public function testSiteOnlyPublish()
    {
        $car = \App\Admin\Dashboard\Models\Car::find(1490);
        $car->site_only = 1;
        $car->save();

        // $this->expectsJobs([\App\Core\Jobs\NewCarJob::class]);
        $response = $this->call('POST', '/api/car-publish',
            ['id' => 1490, 'user_types' => [1,2,3,4,5,6]], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJson(['success' => true, 'msg' => 'Oferta exclusiva do seu site criada com sucesso!'])->assertResponseStatus(201);
        $this->seeInDatabase('car_publish', ['car_id' => 1490, 'user_type' => 1]);
        $this->seeInDatabase('car', ['id' => 1490, 'site_only' => true]);

    }

    public function testModeratedCar()
    {

        $this->expectsJobs(\App\Core\Jobs\CarStatusPodioJob::class);
        $response = $this->call('POST', '/api/car-publish',
            ['id' => 1527, 'user_types' => [1,2,3,4,5,6]], [], [], [
                'HTTP_Authorization' => 'Basic ' . base64_encode('rd@repasses.com.br' . ':' . '123'),
                'PHP_AUTH_USER' => 'rd@repasses.com.br',
                'PHP_AUTH_PW' => '123'
            ] );
        $this->seeJson(['success' => true, 'msg' => 'Anúncio encontra-se em análise'])->assertResponseStatus(201);

    }


}
