<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiControllerTest extends TestCase
{
    use DatabaseTransactions;

    public function testVersionCheck()
    {
        $this->withoutMiddleware();
        $this->get('/api/version')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testDefaultVersionCheck()
    {
        $deleted = \DB::delete('delete from version_info');


        $this->withoutMiddleware();
        $this->get('/api/version')
            ->seeJson(['success' => true, 'data' => ['version' => '0.0.1']])
            ->assertResponseOk();

    }

    public function testPopulateAnnounce()
    {
        $this->withoutMiddleware();
        $this->get('/api/populate-announce/0')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testPopulateYear()
    {
        $this->withoutMiddleware();
        $this->get('/api/populate-year/0/144')
            ->seeJson(['success' => true])
            ->assertResponseOk();

    }

    public function testPopulateModelError()
    {
        $this->withoutMiddleware();
        $this->get('/api/populate-model')
            ->seeJson(['success' => false])
            ->assertResponseStatus(400);
    }

    public function testPopulateModel()
    {
        $user = \App\Auth\Models\User::where('email', 'a@a.com')->first();

        $this->withoutMiddleware();
        $this->actingAs($user)
            ->get('/api/populate-model/134/2012')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testPopulateEdit()
    {
        $user = \App\Auth\Models\User::where('email', 'a@a.com')->first();

        $this->withoutMiddleware();
        $this->actingAs($user)
            ->get('/api/populate-edit/0/2012')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testPopulateReason()
    {
        $this->withoutMiddleware();
        $this->get('/api/populate-reason')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }


}
