<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiProductsControllerTest extends TestCase
{
    use DatabaseTransactions;

    public function testUserNotLoggedTurbo()
    {
        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => 1489, 'product_id' => 5]);

        $this->assertResponseStatus( 401);

    }

    /**
     * Ticket#1160
     */
    public function testConsumeTurboCarAlreadyTurbo()
    {


        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => 1489, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => false, 'msg' => 'Anúncio não pode ser turbinado (Não está aberto)'])->assertResponseStatus( 409);

    }


    /**
     * Ticket#1160
     */
    public function testConsumeTurbo()
    {
        $this->expectsJobs([\App\Core\Jobs\NewCarJob::class]);
        $car_id = 1213;
        $car = \App\Admin\Dashboard\Models\Car::find($car_id);
        $car->car_status_id = 1;
        $car->save();

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car_id, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->assertResponseStatus( 200);

    }

    public function testCanParticularConsumeTurbo()
    {
        // Usuário particular sem loja e sem plano
        $email = 'mateus-particular@gmail.com';
        $pass = '123';
        $car = 1643;

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($email . ':' . $pass),
                'PHP_AUTH_USER' => $email,
                'PHP_AUTH_PW' => $pass
            ]);

        $this->seeJson(['success' => false, 'msg' => 'Usuário não está autorizado a turbinar anúncios'])->assertResponseStatus( 403);
    }

    public function testCanChiefWhithoutPlanConsumeTurbo()
    {

        // Usuário diretor de loja e sem plano
        $email = 'sandroamorim177@gmail.com';
        $pass = '123';
        $car = 1201;

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($email . ':' . $pass),
                'PHP_AUTH_USER' => $email,
                'PHP_AUTH_PW' => $pass
            ]);

        $this->seeJson(['success' => false, 'msg' => 'Usuário não está autorizado a turbinar anúncios'])->assertResponseStatus( 403);

    }

    public function testCanManagerWithoutPlanConsumeTurbo()
    {

        // Usuário gerente de loja e sem plano
        $email = 'gerente@semplano.com';
        $pass = '12345678';
        $car = 1739;

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($email . ':' . $pass),
                'PHP_AUTH_USER' => $email,
                'PHP_AUTH_PW' => $pass
            ]);

        $this->seeJson(['success' => false, 'msg' => 'Usuário não está autorizado a turbinar anúncios'])->assertResponseStatus( 403);

    }

    public function testCanSalesmanWithoutPlanConsumeTurbo()
    {

        // Usuário vendedor de loja e sem plano
        $email = 'vendedor@semplano.com';
        $pass = '12345678';
        $car = 1740;

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($email . ':' . $pass),
                'PHP_AUTH_USER' => $email,
                'PHP_AUTH_PW' => $pass
            ]);

        $this->seeJson(['success' => false, 'msg' => 'Usuário não está autorizado a turbinar anúncios'])->assertResponseStatus( 403);

    }

    public function testCanSalesmanWithPlanConsumeTurbo()
    {

        $this->expectsJobs([\App\Core\Jobs\NewCarJob::class]);

        $email = 'zero@zero.com';
        $pass = '123';
        $car = 1711;
        $thecar = \App\Admin\Dashboard\Models\Car::find($car);
        $thecar->car_status_id = 1;
        $thecar->save();

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($email . ':' . $pass),
                'PHP_AUTH_USER' => $email,
                'PHP_AUTH_PW' => $pass
            ]);

        $this->assertResponseStatus( 200);

    }

    public function testCanManagerWithPlanConsumeTurbo()
    {

        $this->expectsJobs([\App\Core\Jobs\NewCarJob::class]);

        $email = 'l@l.com';
        $pass = '123';
        $car = 1703;

        $model = \App\Admin\Dashboard\Models\Car::find($car);
        $model->car_status_id = 1;
        $model->save();

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($email . ':' . $pass),
                'PHP_AUTH_USER' => $email,
                'PHP_AUTH_PW' => $pass
            ]);

        $this->assertResponseStatus( 200);

    }

    public function testCanChiefWithPlanConsumeTurbo()
    {

        $this->expectsJobs([\App\Core\Jobs\NewCarJob::class]);

        $email = 'jota@gmail.com';
        $pass = '123';
        $car = 1708;
        $model = \App\Admin\Dashboard\Models\Car::find($car);
        $model->car_status_id = 1;
        $model->save();

        $response = $this->call('POST', '/api/products/consume/turbo', ['car_id' => $car, 'product_id' => 5], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($email . ':' . $pass),
                'PHP_AUTH_USER' => $email,
                'PHP_AUTH_PW' => $pass
            ]);

        $this->assertResponseStatus( 200);

    }
}
