<?php

use App\Admin\Dashboard\Models\Store\Store;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiStoreControllerTest extends TestCase
{
    use DatabaseTransactions;


    public function testStoreStaffDefault()
    {

        $this->withoutMiddleware();
        // store 1, user 4
        // $user = \App\Auth\Models\User::find(4);
        // $store = \App\Admin\Dashboard\Models\Store\Store::find(1);

        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getProfessionalRole();

        $user->roles()->sync($roles);

        $store = factory(\App\Admin\Dashboard\Models\Store\Store::class)->create([
            'user_id' => $user->id
        ]);

        $store->staff()->attach($user->id, ['role_id' => 2, 'status'=> 1] );

        
        $this->actingAs($user);
        $this->json('GET', "/api/v2/store/{$store->id}/staff")
            ->seeJson([
                'success' => true,
                'data' => [
                    'current_page' => 1,
                    'items' => [
                        [
                            "cell_phone" => $user->cell_phone,
                            "cpf" => $user->document,
                            "email" => $user->email,
                            "id" => $user->id,
                            "name" => $user->name,
                            "phone" => $user->phone,
                            "qty_cars" => $user->anuncios()->count(),
                            "role" => "Diretor",
                            "status" => 1
                        ]
                    ],
                    'per_page' => 10,
                    'totals' => 1
                ]
            ]);

    }

    public function testStoreMeParticular()
    {
        // $this->markTestSkipped('Precisa de alteração');
        // Se a loja for particular deve retornar só o usuário logado
        $this->withoutMiddleware();
        // $user = \App\Auth\Models\User::where('user_type', 3)->where('is_aprovado', 1)->first();
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getIndividualRole();
        $user->roles()->sync($roles);
        
        $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();

        $store->staff()->attach($user->id, ['role_id' => 4, 'status'=> 1] );


        $this->actingAs($user);
        $this->json('GET', "/api/v2/store/{$store->id}/staff/{$user->id}")
            ->seeJsonEquals([
                'success' => true,
                'data' => [
                    "cell_phone" => $user->cell_phone,
                    'cpf' => $user->document,
                    'email' => $user->email,
                    'id' => $user->id,
                    'name' => $user->name,
                    'phone' => $user->phone,
                    'status' => 1,
                    'qty_cars' => $user->anuncios()->count(),
                    'role' => 'Vendedor'
                ]
            ]);
    }

    public function testStoreMeStaffLojista()
    {
        // $this->markTestSkipped('Precisa de alteração');
        // Se a loja for particular deve retornar só o usuário logado
        $this->withoutMiddleware();
        //
        // cadastrar uma loja
        // cadastra um user
        // logar e pesquisar

        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getProfessionalRole();

        $user->roles()->sync($roles);

        $store = factory(\App\Admin\Dashboard\Models\Store\Store::class)->create([
            'user_id' => $user->id
        ]);

        $store->staff()->attach($user->id, ['role_id' => 2, 'status'=> 1] );

        $this->actingAs($user);
        $this->json('GET', "/api/v2/store/{$store->id}/staff/{$user->id}")
            ->seeJson([
                    "cell_phone" => $user->cell_phone,
                    'cpf' => $user->document,
                    'email' => $user->email,
                    'id' => $user->id,
                    'name' => $user->name,
                    'phone' => $user->phone,
                    'status' => 1,
                    'qty_cars' => $user->anuncios()->count()
            ]);
    }

    /*
     * plano de testes para getCarsByStore
     * 1 - loja não existe (DONE)
     * 2 - usuário não pertence a loja ($user tem uma loja mas é diferente de $store_id do request) (DONE)
     * 3 - diretor consulta carros da loja (DONE)
     * 4 - gerente consulta carros da loja (DONE)
     * 5 - vendedor consulta carros da loja (DONE)
     * 6 - particular consulta carros da loja (e ve tudo) (DONE)
     * Refactor pro chamado 1500
     * 6 - particular consulta carros da loja e vê só seus carros
     */

    public function testCarsByStoreNotFound()
    {
        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 2,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        $this->withoutMiddleware();
        $this->actingAs($user);
        $response = $this->json('GET', '/api/v2/store/9999/cars')
            ->seeJsonStructure(['success', 'msg'])
            ->assertResponseStatus(404);
    }

    public function testCarsByStoreNotInStore()
    {
        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        
        /** @var \App\Auth\Models\User $user */
        $user2 = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getProfessionalRole();

        $user2->roles()->sync($roles);

        $store2 = factory(\App\Admin\Dashboard\Models\Store\Store::class)->create([
            'user_id' => $user->id
        ]);

        $store2->staff()->attach($user2->id, ['role_id' => 2, 'status'=> 1] );

        $store = factory(Store::class)->make();
        
        $this->withoutMiddleware();
        $this->actingAs($user);
        $this->json('GET', "/api/v2/store/{$store2->id}/cars")
            ->seeJsonStructure(['success', 'msg'])
            ->assertResponseStatus(401);

    }

    public function testCarsByStoreDirector()
    {
        $this->withoutMiddleware();

        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        $roles = \App\Admin\Role\Models\Role::getProfessionalRole();
        $user->roles()->sync($roles);
        $store = factory(\App\Admin\Dashboard\Models\Store\Store::class)->create([
            'user_id' => $user->id
        ]);
        $store->staff()->attach($user->id, ['role_id' => 2, 'status'=> 1] );

        $this->actingAs($user);
        $this->json('GET', "/api/v2/store/{$store->id}/cars")
            ->seeJsonStructure(['success', 'data'])
            ->assertResponseStatus(200);

    }

    public function testCarsByStoreManager()
    {

        $this->withoutMiddleware();

        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        $roles = \App\Admin\Role\Models\Role::getProfessionalRole();
        $user->roles()->sync($roles);
        $store = factory(\App\Admin\Dashboard\Models\Store\Store::class)->create([
            'user_id' => $user->id
        ]);
        $store->staff()->attach($user->id, ['role_id' => 2, 'status'=> 1] );

        $manager = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        $manager->roles()->sync([3,5]);

        $store->staff()->attach($manager->id, ['role_id' => 3, 'status' => 1]);

        $this->actingAs($manager);
        $this->json('GET', "/api/v2/store/{$store->id}/cars")
            ->seeJsonStructure(['success', 'data'])
            ->assertResponseStatus(200);

    }

    public function testCarsByStoreSalesman()
    {

        $this->withoutMiddleware();

        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        $roles = \App\Admin\Role\Models\Role::getProfessionalRole();
        $user->roles()->sync($roles);
        $store = factory(\App\Admin\Dashboard\Models\Store\Store::class)->create([
            'user_id' => $user->id
        ]);
        $store->staff()->attach($user->id, ['role_id' => 2, 'status'=> 1] );

        $salesman = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 1,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        $salesman->roles()->sync([4,5]);

        $store->staff()->attach($salesman->id, ['role_id' => 4, 'status' => 1]);

        $this->actingAs($salesman);
        $this->json('GET', "/api/v2/store/{$store->id}/cars")
            ->seeJsonStructure(['success', 'data'])
            ->assertResponseStatus(200);

    }

    public function testGetCarsByStoreParticular()
    {
        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();
        $roles = \App\Admin\Role\Models\Role::getIndividualRole();
        $user->roles()->attach($roles);
        $store->staff()->attach($user->id, ['role_id' => 4, 'status' => 1]);

        $this->withoutMiddleware();
        $this->actingAs($user);
        $this->json('GET', "/api/v2/store/{$store->id}/cars")
            ->seeJsonStructure(['success', 'data'])
            ->assertResponseStatus(200);

    }



}
