<?php

use App\Admin\Dashboard\Models\Car;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class CarUtilTest extends TestCase
{
    use DatabaseTransactions;

    private $car;

    public function setUp()
    {
        parent::setUp();
        $this->car = Car::find(967);
    }

    public function testCarUtilEdge()
    {
        $carFavorite = \App\Admin\Dashboard\Models\CarFavorite::create(['car_id' => $this->car->id, 'user_id' => 11]);

        $car = $this->car;
        $carUtil = new \App\Repasse\CarUtil($car);

        $carObj = $carUtil->getCarObject(11);
        $this->assertObjectHasAttribute('is_comprador', $carObj);
        $this->assertTrue($carObj->is_comprador);
        $this->assertTrue($carObj->is_favorite);

    }


    public function testCarUtilGetNegotiations()
    {
        $car = $this->car;
        $carUtil = new \App\Repasse\CarUtil($car);
        $negotiations = $carUtil->getNegotiations();

        $this->assertObjectHasAttribute('message',$negotiations[0]);

    }

    public function testCarUtilGetNegotiationsWithMessage()
    {
        $car = Car::find(1691);
        $carUtil = new \App\Repasse\CarUtil($car);
        $negotiations = $carUtil->getNegotiations();

        $this->assertObjectHasAttribute('message',$negotiations[0]);

    }

    public function testSetFirstPhoto()
    {
        // 826 photo id
        // 999 car_id
        $car = Car::find(999);
        $carUtil = new \App\Repasse\CarUtil($car);
        $set = $carUtil->setFirstPhoto(826);
        $this->assertTrue($set);
        $this->seeInDatabase('car_photo', ['id' => 826, 'car_id' => 999, 'photo_order' => 1]) ;

    }

    public function testSetFirstPhotoNoPhoto()
    {

        $car = Car::find(1216);
        $carUtil = new \App\Repasse\CarUtil($car);
        $set = $carUtil->setFirstPhoto(9999);
        $this->assertFalse($set);

    }

    public function testCarObjectWithSiteUrl()
    {
        $store_id = 4;
        $car = Car::where('store_id', $store_id)->first();
        $carUtil = new \App\Repasse\CarUtil($car);
        $this->assertObjectHasAttribute('site_url', $carUtil->getCarObject());
    }

    public function testCarObjectWithoutSiteUrl()
    {

        $store_id = 3;
        $car = Car::where('store_id', $store_id)->first();
        $carUtil = new \App\Repasse\CarUtil($car);
        $this->assertObjectNotHasAttribute('site_url', $carUtil->getCarObject());

    }

    public function testCarObjectWithoutStore()
    {
        $car = $this->car;
        $car->store_id = null;
        $car->save();
        $carUtil = new \App\Repasse\CarUtil($car);
        $this->assertObjectNotHasAttribute('site_url', $carUtil->getCarObject());

    }

    public function testCarNegotiationsWithBuyer()
    {

        $car = Car::find(1398);
        $carUtil = new \App\Repasse\CarUtil($car);
        $negotiations = $carUtil->getNegotiations();

        $this->assertObjectHasAttribute('message',$negotiations[0]);

    }



}
